@@ -1,13 +1,39 @@
 from curlylint.check_node import CheckNode, build_tree
-from curlylint.issue import Issue, IssueLocation
+from curlylint.issue import Issue
 
 ARIA_ROLE = "aria_role"
 
 RULE = {
     "id": "aria_role",
     "type": "accessibility",
-    "docs": {"description": "role attributes must be valid", "url": ""},
-    "schema": [],
+    "docs": {
+        "description": "Elements with ARIA roles must use a valid, non-abstract ARIA role",
+        "url": "https://www.curlylint.org/docs/rules/aria_role",
+        "impact": "Serious",
+        "tags": ["cat.language", "wcag2a", "wcag412"],
+        "resources": [
+            "[WAI-ARIA Role Definitions](https://www.w3.org/TR/wai-aria/#role_definitions)",
+            "[WCAG2.1 SC 4.2.1: Name, Role, Value (Level A)](https://www.w3.org/WAI/WCAG21/Understanding/name-role-value)",
+            "[eslint-plugin-jsx-a11y, aria-role](https://github.com/evcohen/eslint-plugin-jsx-a11y/blob/master/docs/rules/aria-role.md)",
+        ],
+    },
+    "schema": {
+        "$schema": "http://json-schema.org/draft/2019-09/schema#",
+        "oneOf": [
+            {
+                "const": True,
+                "title": "All role attributes must be valid.",
+                "examples": [True],
+            },
+            {
+                "type": "array",
+                "items": {"type": "string"},
+                "uniqueItems": True,
+                "title": "All role attributes must match the provided list",
+                "examples": [["search", "presentation", "alert"]],
+            },
+        ],
+    },
 }
 
 VALID_ROLES = (
@@ -149,12 +175,9 @@ def find_role_errors(node, file, target_roles):
             []
             if attributes["role"] in target
             else [
-                Issue(
-                    IssueLocation(
-                        file_path=file.path,
-                        line=node.value.begin.line + 1,
-                        column=node.value.begin.column + 1,
-                    ),
+                Issue.from_node(
+                    file,
+                    node,
                     "The `role` attribute needs to have a valid value",
                     "aria_role",
                 )
