@@ -1,4 +1,4 @@
-import collections
+from collections.abc import Iterable
 
 
 def flatten(_list):
@@ -6,9 +6,7 @@ def flatten(_list):
     Deeply flattens an iterable.
     """
     for el in _list:
-        if isinstance(el, collections.Iterable) and not isinstance(
-            el, (str, bytes)
-        ):
+        if isinstance(el, Iterable) and not isinstance(el, (str, bytes)):
             yield from flatten(el)
         else:
             yield el
